@@ -1,19 +1,12 @@
 #include "__oo2c.h"
-#include "__config.h"
 
 #define _POSIX_SOURCE  /* file uses POSIX.1 functions */
 #include <stddef.h>
 #include <stdlib.h>
 #include <stdio.h>
-#if HAVE_UNISTD_H
 #include <unistd.h>
-#elif HAVE_IO_H
-#include <io.h>
-#endif
 #include <signal.h>
-#if HAVE_PWD_H
 #include <pwd.h>
-#endif
 #include <string.h>
 #include "__mini_gc.h"
 
@@ -59,7 +52,7 @@ INTEGER Rts_ArgNumber (void) {
   return (INTEGER) (_program_argc-1);
 }
 
-void Rts_GetArg (INTEGER num, OOC_CHAR *arg) {
+void Rts_GetArg (INTEGER num, CHAR *arg) {
   INTEGER i = -1;
 
   do {
@@ -72,12 +65,12 @@ void Rts_Terminate (void) {
   exit((int) _program_exit_code);
 }
 
-void Rts_Error (const OOC_CHAR *msg) {
+void Rts_Error (const CHAR *msg) {
   fprintf (stderr, "*** Error: %s\n", msg);
   exit(1);
 }
 
-void Rts_Assert (OOC_BOOLEAN expr, const OOC_CHAR *msg) {
+void Rts_Assert (BOOLEAN expr, const CHAR *msg) {
   if (!expr) {
     fprintf (stderr, "*** Assert: %s\n", msg);
     exit(1);
@@ -98,7 +91,7 @@ void Rts_TerminationProc (void (*func)(void)) {
   exit(1);
 }
 
-INTEGER Rts_System (const OOC_CHAR *command) {
+INTEGER Rts_System (const CHAR *command) {
   return (INTEGER) system((const char*) command);
 }
 
@@ -126,11 +119,7 @@ static RETSIGTYPE Rts_SignalHandler (int sig) {
     Rts_noSignalHandlerInProgress = 0;
     Rts_RunTermProcs();
   }
-#if HAVE_RAISE
-  raise(sig);
-#else
   kill(getpid(), sig);   /* raise signal to call default handler */
-#endif
 }
 
 static void Rts_CatchSignal (int sig) {
@@ -143,8 +132,7 @@ static void Rts_CatchSignal (int sig) {
 }
 
 
-void Rts_GetUserHome (OOC_CHAR *home, const OOC_CHAR *user) {
-#if HAVE_PWD_H
+void Rts_GetUserHome (CHAR *home, const CHAR *user) {
   struct passwd *entry;
 
   if (*user)
@@ -156,12 +144,9 @@ void Rts_GetUserHome (OOC_CHAR *home, const OOC_CHAR *user) {
     strcpy((char*) home, entry->pw_dir);  /* danguerous */
   else
     home[0] = '\000';
-#else
-  home[0] = '\000';
-#endif
 }
 
-OOC_BOOLEAN Rts_GetEnv(OOC_CHAR* var, const OOC_CHAR* name) {
+BOOLEAN Rts_GetEnv(CHAR* var, const CHAR* name) {
   char *value;
 
   value = getenv((const char*)name);
@@ -190,13 +175,9 @@ void Rts_init (void) {
 #endif
   Rts_CatchSignal(SIGABRT);
   /* termination signals */
-#ifdef SIGHUP
   Rts_CatchSignal(SIGHUP);
-#endif
   Rts_CatchSignal(SIGINT);
-#ifdef SIGQUIT
   Rts_CatchSignal(SIGQUIT);
-#endif
   Rts_CatchSignal(SIGTERM);
   /* normal program exit */
 #if HAVE_ATEXIT
